@@ -1,5 +1,6 @@
-import json
+import simplejson as json
 
+from simplejson.errors import JSONDecodeError
 from abc import ABCMeta, abstractmethod
 from .adapters import WalletAdapterBase
 from .wallet_exceptions import WalletException
@@ -8,8 +9,12 @@ from .zmq_notifier import ZMQNotifier
 class WalletBase(metaclass=ABCMeta):
 
     def load_json(self, val: str, raw: bool):
+        invalid_type = type(val) in [dict, list, float]
         if raw: return val
-        return json.loads(val)
+        elif invalid_type: return val
+        else:
+            try: return json.loads(val)
+            except JSONDecodeError: return val
 
     @abstractmethod
     def __init__(self, *args): pass
